#!/bin/sh
PATH=/usr/bin:/bin:/usr/sbin:/sbin

# Converts Fahrenheit to Celcius
f2c() {
  /bin/echo $(( (($1 - 32) * 10 + 9) / 18 ))
}

# Converts Celcius to Fahrenheit
c2f() {
  /bin/echo $(( ($1 * 9) / 5 + 32 ))
}

# Kill the old fan controller
PID=$(/bin/pidof fancontrol)
if [ -n "$PID" ]
  then
         kill -9 $PID
fi

# Checking interval in seconds
update_interval=60
# T1 and T2 in fahrenheit - convert if necessary using c2f function
# Example: "T1=$(c2f 30)" will convert 30C to Fahrenheit
T1=86
T2=110
# Idle-RPM. If you want the Fan to switch of, set this to zero
IDLERPM=0
# Linearly interpolate the fan-speed between RPM1 and RPM2
RPM1=2700
RPM2=3500

# Now loop, check status every $update_interval seconds
while [ 1 ]
do
  # Find out current temperature
  T=`temperature g 0`
  T=${T##*=}
  C=`temperature g 0 | grep -i -c centigrade `
  # Convert to Fahrenheit if output is in Celcius
  if [ $C -gt 0 ]
  then
    T=$(c2f $T)
  fi
  # Check if Temperature is above $T1
  if [ $T -gt $T1 ]; then
	# Keep the fan running
	newRPM=$(( ($RPM1 + ($RPM2 - $RPM1) * ($T - $T1) / ($T2 - $T1)) ))
  else
	# Temp below T1 -> set fan to IDLE-Speed
	newRPM=$IDLERPM
  fi
  fanspeed w $newRPM
  # wait for next cycle
  sleep $update_interval
done
